function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function View(props) {
  var children = props.children,
      style = props.style;
  style = _extends({
    display: 'flex',
    flexDirection: 'column'
  }, style);
  return React__default.createElement("div", Object.assign({}, props, {
    style: style
  }), children);
}

function Text (props) {
  var children = props.children,
      _props$elementType = props.elementType,
      ElementType = _props$elementType === void 0 ? 'p' : _props$elementType,
      style = props.style;
  return React.createElement(ElementType, Object.assign({}, props, {
    style: style
  }), children);
}

function Image(props) {
  var source = props.source;
  return React__default.createElement("img", Object.assign({}, props, {
    src: source === null || source === void 0 ? void 0 : source.uri
  }));
}

function TextInput(props) {
  var value = props.value,
      onChangeText = props.onChangeText,
      onChange = props.onChange;
  onChangeText = onChangeText || onChange;
  return React__default.createElement("input", Object.assign({}, props, {
    onChange: onChangeText,
    value: value
  }));
}

function Button(props) {
  var _children;

  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      style = props.style,
      dontCapitalize = props.dontCapitalize,
      textColor = props.textColor,
      color = props.color,
      onPress = props.onPress,
      onClick = props.onClick;
  style = _extends({
    padding: '10px 20px',
    fontWeight: 600,
    letterSpacing: 1,
    border: 'none'
  }, style, {
    backgroundColor: color || 'rgb(33, 150, 243)',
    color: textColor || '#fff'
  });
  if (!dontCapitalize) children = ((_children = children) === null || _children === void 0 ? void 0 : _children.toString().toUpperCase()) || '';
  return React__default.createElement("button", Object.assign({}, props, {
    onClick: onPress || onClick,
    style: style
  }), children);
}

function Switch(props) {
  var _props$size = props.size,
      size = _props$size === void 0 ? 20 : _props$size,
      value = props.value,
      onValueChange = props.onValueChange,
      _props$thumbColor = props.thumbColor,
      thumbColor = _props$thumbColor === void 0 ? 'silver' : _props$thumbColor,
      _props$trackColor = props.trackColor,
      trackColor = _props$trackColor === void 0 ? {
    "true": null,
    "false": null
  } : _props$trackColor;
  trackColor["true"] = (trackColor === null || trackColor === void 0 ? void 0 : trackColor["true"]) || '#81b0ff';
  trackColor["false"] = (trackColor === null || trackColor === void 0 ? void 0 : trackColor["false"]) || '#767577';
  return React__default.createElement("label", Object.assign({
    style: {
      position: 'relative',
      margin: size / 2
    }
  }, props), React__default.createElement("input", Object.assign({
    style: {
      width: 0,
      height: 0,
      opacity: 0
    }
  }, props, {
    type: 'checkbox',
    value: value,
    onChange: onValueChange
  })), React__default.createElement("span", {
    style: {
      position: 'absolute',
      backgroundColor: value ? trackColor["true"] : trackColor["false"],
      borderRadius: 999,
      display: 'flex',
      alignItems: 'center'
    }
  }, React__default.createElement("span", {
    style: {
      width: size,
      height: size,
      backgroundColor: thumbColor,
      borderRadius: 999,
      display: 'flex',
      transition: '0.2s',
      transform: !value ? 'translateX(0) scale(2)' : 'translateX(200%) scale(2)'
    }
  }), React__default.createElement("span", {
    style: {
      width: size,
      height: size,
      backgroundColor: 'none',
      borderRadius: 999,
      display: 'flex'
    }
  }), React__default.createElement("span", {
    style: {
      width: size,
      height: size,
      backgroundColor: 'none',
      borderRadius: 999,
      display: 'flex'
    }
  })));
}

function FlatList(props) {
  var _props$data = props.data,
      data = _props$data === void 0 ? [] : _props$data,
      keyExtractor = props.keyExtractor,
      RenderItem = props.renderItem;
  return data.map(function (item) {
    RenderItem && React__default.createElement(RenderItem, {
      item: item,
      key: keyExtractor && keyExtractor(item)
    });
  });
}

var capitalize = function capitalize(str) {
  var first = str[0],
      rest = str.slice(1);
  first = first.toUpperCase();
  return first + rest.join('');
};

var index = {
  capitalize: capitalize
};

var ScrollView = View;
var SafeAreaView = View;

exports.Button = Button;
exports.FlatList = FlatList;
exports.Image = Image;
exports.SafeAreaView = SafeAreaView;
exports.ScrollView = ScrollView;
exports.Switch = Switch;
exports.Text = Text;
exports.TextInput = TextInput;
exports.View = View;
exports.services = index;
//# sourceMappingURL=index.js.map
